==> otrs-3.2.1.zip: otrs-3.2.1/bin/fcgi-bin/nph-genericinterface.pl <==
#!/usr/bin/perl
# --
# bin/cgi-bin/nph-genericinterface.pl - the global generic interface handle file
# Copyright (C) 2001-2013 OTRS AG, http://otrs.org/
# --
# $Id: nph-genericinterface.pl,v 1.5 2013/01/22 10:14:10 mg Exp $
# --
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU AFFERO General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
# or see http://www.gnu.org/licenses/agpl.txt.
# --

use strict;
use warnings;

# use ../../ as lib location
use FindBin qw($Bin);
use lib "$Bin/../..";
use lib "$Bin/../../Kernel/cpan-lib";
use lib "$Bin/../../Custom";

use vars qw($VERSION);
$VERSION = qw($Revision: 1.5 $) [1];

# Imports the library; required line
use CGI::Fast;

# load generic interface
use Kernel::GenericInterface::Provider;

# response loop
while ( my $WebRequest = new CGI::Fast ) {

    # create new object
    my $Provider = Kernel::GenericInterface::Provider->new();

    # execute object
    $Provider->Run();
}

==> otrs-5.0.29.zip: otrs-5.0.29/bin/fcgi-bin/nph-genericinterface.pl <==
#!/usr/bin/perl
# --
# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
# --
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU AFFERO General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
# or see http://www.gnu.org/licenses/agpl.txt.
# --

use strict;
use warnings;

# use ../../ as lib location
use FindBin qw($Bin);
use lib "$Bin/../..";
use lib "$Bin/../../Kernel/cpan-lib";
use lib "$Bin/../../Custom";

use CGI::Fast;
use Module::Refresh;

# load generic interface
use Kernel::GenericInterface::Provider;
use Kernel::System::ObjectManager;

# response loop
while ( my $WebRequest = new CGI::Fast ) {

    # Reload files in @INC that have changed since the last request.
    eval {
        Module::Refresh->refresh();
    };

    local $Kernel::OM = Kernel::System::ObjectManager->new(
        'Kernel::System::Web::Request' => {
            WebRequest => $WebRequest,
            }
    );
    my $Provider = Kernel::GenericInterface::Provider->new();

    $Provider->Run();
}
